@@ -1,4 +1,3 @@
-empty=function (df) 
-{
+empty <- function(df) {
   is.null(df) || nrow(df) == 0 || ncol(df) == 0
-}
\ No newline at end of file
+}
